[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
12/31: gnu: coreutils: Remove libcap dependency for the Hurd.
From: |
guix-commits |
Subject: |
12/31: gnu: coreutils: Remove libcap dependency for the Hurd. |
Date: |
Thu, 12 Mar 2020 02:59:05 -0400 (EDT) |
janneke pushed a commit to branch wip-hurd
in repository guix.
commit 07dd01760675036664b9bee94cb69d6d3ce8bc0e
Author: Jan Nieuwenhuizen <address@hidden>
AuthorDate: Sat Mar 7 03:53:38 2020 -0500
gnu: coreutils: Remove libcap dependency for the Hurd.
* gnu/packages/linux.scm (libcap)[supported-systems]: Remove the Hurd.
* gnu/packages/base.scm (coreutils)[inputs]: Include libcap only for
supported
systems. Fixes building on the Hurd.
---
gnu/packages/base.scm | 12 +++++++-----
gnu/packages/linux.scm | 1 +
2 files changed, 8 insertions(+), 5 deletions(-)
diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index e1959b9..6bbe132 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -2068,6 +2068,7 @@ configuration (iptunnel, ipmaddr).")
(assoc-ref %outputs "out"))
"RAISE_SETFCAP=no")))
(native-inputs `(("perl" ,perl)))
+ (supported-systems (delete "i586-gnu" %supported-systems))
(home-page "https://sites.google.com/site/fullycapable/")
(synopsis "Library for working with POSIX capabilities")
(description
- branch wip-hurd created (now 26973d5), guix-commits, 2020/03/12
- 04/31: gnu: java-jansi-native: Compile fix for the Hurd., guix-commits, 2020/03/12
- 05/31: gnu: make: Support for the Hurd., guix-commits, 2020/03/12
- 03/31: gnu: hurd: Fix hurd-target?, add hurd-system?., guix-commits, 2020/03/12
- 01/31: gnu: flex-2.6.1: Build fix for the Hurd., guix-commits, 2020/03/12
- 07/31: gnu: fontconfig: Build fix for the Hurd., guix-commits, 2020/03/12
- 06/31: gnu: less: Build fix for the Hurd., guix-commits, 2020/03/12
- 10/31: gnu: cross-libc: Build fix for the Hurd., guix-commits, 2020/03/12
- 12/31: gnu: coreutils: Remove libcap dependency for the Hurd.,
guix-commits <=
- 08/31: gnu: glibc: Add and update patches for the Hurd., guix-commits, 2020/03/12
- 13/31: gnu: pciutils: Build fixes for the Hurd., guix-commits, 2020/03/12
- 09/31: gnu: glibc: Add signal SA_SIGINFO support for the Hurd., guix-commits, 2020/03/12
- 02/31: gnu: grub: Support for the Hurd., guix-commits, 2020/03/12
- 16/31: gnu: screen: Build fix for the Hurd., guix-commits, 2020/03/12
- 11/31: gnu: shadow: Add linux-pam dependency for the Hurd., guix-commits, 2020/03/12
- 20/31: gnu: commencement: gnumach-headers-boot0: Build from tarball., guix-commits, 2020/03/12
- 26/31: gnu: commencement: static-bash-for-glibc: Hurd build fix., guix-commits, 2020/03/12
- 23/31: gnu: commencement: glibc-intermediate: Build fixes for the Hurd., guix-commits, 2020/03/12
- 15/31: gnu: inetutils: Support for the Hurd., guix-commits, 2020/03/12
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index f562a8f..0307dc4 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -303,11 +303,13 @@ used to apply commands with arbitrarily long arguments.")
(inputs `(("acl" ,acl) ; TODO: add SELinux
("gmp" ,gmp) ;bignums in 'expr', yay!
- ;; Drop the dependency on libcap when cross-compiling since it's
- ;; not quite cross-compilable.
- ,@(if (%current-target-system)
- '()
- `(("libcap" ,libcap))))) ;capability support is 'ls', etc.
+ ;; Do not use libcap when cross-compiling since it's not quite
+ ;; cross-compilable; and use it only for supported systems.
+ ,@(if (and (not (%current-target-system))
+ (not (member (%current-system)
+ (package-supported-systems libcap))))
+ `(("libcap" ,libcap)) ;capability support in 'ls', etc.
+ '())))
(native-inputs
;; Perl is needed to run tests in native builds, and to run the bundled
;; copy of help2man. However, don't pass it when cross-compiling since